@@ -8,6 +8,18 @@
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
     </message>
+    <message>
+        <source>Theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use theme's wallpapers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keep my current wallpapers</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Theme customizations applied!</source>
         <translation type="unfinished"></translation>
